atomate.feff.fireworks package — atomate 0.3 documentation

# atomate.feff.fireworks package

## Submodules

## atomate.feff.fireworks.core module

class `atomate.feff.fireworks.core.` `EELSFW`(absorbing_atom, structure, spectrum_type, edge=u'K', radius=10.0, name=u'EELS spectroscopy', beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, feff_input_set=None, feff_cmd=u'feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(absorbing_atom, structure, spectrum_type, edge=u'K', radius=10.0, name=u'EELS spectroscopy', beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, feff_input_set=None, feff_cmd=u'feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

    Write the input set for FEFF-EELSS spectroscopy, run feff and insert the core-loss spectrum to the database(or dump to a json file if db_file=None).

    Args:
      absorbing_atom (str): absorbing atom symbol structure (Structure): input structure spectrum_type (str): “ELNES” or “EXELFS” edge (str): absorption edge radius (float): cluster radius in angstroms name (str) feff_input_set (FeffDictSet) feff_cmd (str): path to the feff binary override_default_feff_params (dict): override feff tag settings. db_file (str): path to the db file. parents (Firework): Parents of this particular Firework. FW or list of FWS. metadata (dict): meta data **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.feff.fireworks.core.` `XASFW`(absorbing_atom, structure, spectrum_type, edge=u'K', radius=10.0, name=u'XAS spectroscopy', feff_input_set=None, feff_cmd=u'feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(absorbing_atom, structure, spectrum_type, edge=u'K', radius=10.0, name=u'XAS spectroscopy', feff_input_set=None, feff_cmd=u'feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

    Write the input set for FEFF-XAS spectroscopy, run feff and insert the absorption coefficient to the database(or dump to a json file if db_file=None).

    Args:
      absorbing_atom (str): absorbing atom symbol structure (Structure): input structure spectrum_type (str): “EXAFS” or “XANES” edge (str): absorption edge radius (float): cluster radius in angstroms name (str) feff_input_set (FeffDictSet) feff_cmd (str): path to the feff binary override_default_feff_params (dict): override feff tag settings. db_file (str): path to the db file. parents (Firework): Parents of this particular Firework. FW or list of FWS. metadata (dict): meta data **kwargs: Other kwargs that are passed to Firework.__init__.

## Module contents